A derivative can be used to describe the rate of change at a single point, or the *instantaneous velocity*.

The formula used to calculate the average rate of change looks like this:
$$ \dfrac{f(b) - f(a)}{b - a} $$
Interpreting it, this can be described as the change in $y$ over the change in $x$.

- Speed is always positive
- Velocity is directional

As the distance between the two points $a$ and $b$ grow smaller, we get closer and closer to the instantaneous velocity of a point. Limits are suited to describing the behavior of a function as it approaches a point.

If we have the coordinate pair $(a, f(a))$, and the value $h$ is the distance between $a$ and another $x$ value, the coordinates of that point can be described as ($(a + h, f(a + h))$. With this info:
- The slope of the secant line can be described as $\dfrac{f(a + h) - f(a)}{a + h - a}$, which simplifies to $\dfrac{f(a + h) - f(a)}{h}$. 
- The slope of the *tangent line* or the *instantaneous velocity* can be found by taking the limit of the above function as the distance ($h$) approaches zero:
$$\lim_{h \to 0}\dfrac{f(a + h) - f(a)}{h}$$
The above formula can be used to find the *derivative*. This may also be referred to as the *instantaneous velocity*, or the *instantaneous rate of change*.

## Examples

> Differentiate $f(x) = 4\sqrt[3]{x} - \dfrac{1}{x^6}$ 

1. $f(x) = 4\sqrt[3]{x} = \dfrac{1}{x^6}$
2. $= 4x^\frac{1}{3} - x^{-6}$  
3. $f'(x) = \dfrac{1}{3} * 4x^{-\frac{2}{3}} -(-6)(x^{-6-1})$ 
4. $= 4x^{-2-\frac{2}{3}} + 6x^{-7}$
5. $= \dfrac{4}{3\sqrt[3]{x^2}} + \dfrac{6}{x^7}$
# Point Slope Formula (Review)
$$  y - y_1 = m(x-x_1) $$
Given that $m = f'(a)$ and that $(x_1, y_1) = (a, f(a))$, you get the equation:
 $$ y - f(a) = f'(a)(x - a) $$
As a more practical example, given an equation with a slope of $6$ at the point $(-2, -4)$:
$$ y - (-4) = 6(x - -2)$$
Solving for $y$ looks like this:
1. $y + 4 = 6(x + 2)$
2. $y = 6(x + 2) - 4$ 
3. $y = 6x + 12 - 4$
4. $y = 6x + 8$ 
# Line Types
## Secant Line
A **Secant Line** connects two points on a graph.

A **Tangent Line** represents the rate of change or slope at a single point on the graph.

# Notation
Given the equation $y = f(x)$, the following are all notations used to represent the derivative of $f$ at $x$:
- $f'(x)$
- $\dfrac{d}{dx}f(x)$
- $y'$
- $\dfrac{dy}{dx}$
- $\dfrac{df}{dx}$
- "Derivative of $f$ with respect to $x$"

# Functions that are not differentiable at a given point
- Where a function is not defined
- Where a sharp turn takes place
- If the slope of the tangent line is vertical

# Higher Order Derivatives
- Take the derivative of a derivative

# Constant Rule
The derivative of a constant is always zero.
$$ \dfrac{d}{dx}[c] = 0$$
For example, the derivative of the equation $f(x) = 3$ is $0$. 
# Derivative of $x$
The derivative of $x$ is one.

For example, the derivative of the equation $f(x) = x$ is $1$, and the derivative of the equation $f(x) = 3x$ is $3$. 

# Exponential Derivative Formula
Using the definition of a derivative to determine the derivative of $f(x) = x^n$, where $n$ is any natural number.

$$ f'(x) = \lim_{h \to 0} \dfrac{(x + h)^n - x^n}{h} $$
- Using pascal's triangle, we can approximate $(x + h)^n$
```
    1
   1 1
  1 2 1
 1 3 3 1
1 4 6 4 1 
```

- Where $n = 0$: $(x + h)^0  = 1$
- Where $n = 1$: $(x +h)^1 = 1x + 1h$
- Where $n = 2$: $(x +h)^2 = x^2 + 2xh + h^2$
- Where $n = 3$: $(x + h)^3 = 1x^3h^0 + 3x^2h^1 + 3x^1h^2 + 1x^0h^3 = 1x^3 + 3x^2h + 3xh^2 + 1h^3$

Note that the coefficient follows the associated level of Pascal's Triangle (`1 3 3 1`), and $x$'s power decrements, while $h$'s power increments. The coefficients of each pair will always add up to $n$. Eg, $3 + 0$, $2 + 1$, $1 + 2$, and so on. The **second** term in the polynomial created will have a coefficient of $n$. 

$$ \dfrac{(x + h)^n - x^n}{h} = \lim_{h \to 0} \dfrac{(x^n + nx^{n-1}h + P_{n3}x^{n-2}h^2 + \cdots + h^n)-x^n}{h} $$ $P$ denotes some coefficient found using Pascal's triangle.

$x^n$ cancels out, and then $h$ can be factored out of the binomial series. 

This leaves us with:
$$ \lim_{h \to 0} nx^{n-1} + P_{n3} x^{n-2}*0 \cdots v * 0 $$

The zeros leave us with:

$$ f(x) = n, \space f'(x) = nx^{n-1} $$
# Sum and Difference Rules
$$ \dfrac{d}{dx}(f(x) \pm g(x)) = f'(x) \pm g'(x) $$

# Product Rule
$$ \dfrac{d}{dx} (f(x) * g(x)) = \lim_{h \to 0} \dfrac{f(x +h) * g(x + h) - f(x)g(x)}{h} $$
This is done by adding a value equivalent to zero to the numerator ($f(x + h)g(x) - f(x + h)g(x)$):
$$ \dfrac{d}{dx} (f(x) * g(x)) = \lim_{h \to 0} \dfrac{f(x +h) * g(x + h) + f(x + h)g(x) - f(x+h)g(x) - f(x)g(x)}{h} $$

From here you can factor out $f(x + h)$ from the first two terms, and a $g(x)$ from the next two terms.

Then break into two different fractions:

$$\lim_{h \to 0} \dfrac{f(x + h)}{1} * \dfrac{(g(x + h) - g(x))}{h)} + \dfrac{g(x)}{1} *\dfrac{f(x + h) - f(x)}{h} $$
From here, you can take the limit of each fraction, therefore showing that to find the derivative of two values multiplied together, you can use the formula:
$$ \dfrac{d}{dx}(f(x) * g(x)) = f(x) * g'(x) + f'(x)*g(x) $$

# Constant Multiple Rule
$$ \dfrac{d}{dx}[c*f(x)] = c * f'(x) $$
# Quotient Rule
$$ \dfrac{d}{dx}(\dfrac{f(x)}{g(x)}) = \dfrac{f'(x)g(x) -f(x)g'(x)}{(g(x))^2}  $$

# Exponential Rule
$$ \dfrac{d}{dx} e^x = e^x $$
$$ \dfrac{d}{dx}a^x = a^x*(\ln(a)) $$
for all $a > 0$


# Logarithms

For natural logarithms:
$$ \dfrac{d}{dx} \ln |x| = \dfrac{1}{x} $$

For other logarithms:
$$ \dfrac{d}{dx} \log_a x = \dfrac{1}{(\ln a) x}$$
When solving problems that make use of logarithms, consider making use of logarithmic properties to make life easier:
$$ \ln(\dfrac{x}{y}) = \ln(x) - \ln(y) $$
$$ \ln(a^b) = b\ln(a) $$
## Logarithmic Differentiation
This is used when you want to take the derivative of a function raised to a function ($f(x)^{g(x)})$

1. $\dfrac{d}{dx} x^x$
2. $y = x^x$
3. Take the natural log of both sides: $\ln y = \ln x^x$
4. $\ln(y) = x*\ln(x)$
5. Use implicit differentiation: $\dfrac{d}{dx} \ln y = \dfrac{d}{dx} x \ln x$
6. Solve for $\dfrac{dy}{dx}$: $\dfrac{1}{y} \dfrac{dy}{dx} = 1 * \ln x + x * \dfrac{1}{x}$ 
7. $\dfrac{dy}{dx} = (\ln x + 1) * y$
8. Referring back to step 2, $y = x^x$, so the final form is:
9. $\dfrac{dy}{dx} = (\ln(x) + 1)x^x$

### Examples
> Find the derivative of $(7x + 2)^x$

1. $\ln y = \ln((7x+2)^x)$
2. $\ln y = x*\ln(7x + 2)$ 
3. $\dfrac{dy}{dx} \dfrac{1}{y} =  \dfrac{7x}{7x + 2} * \ln(7x+2)$ 
4. $\dfrac{dy}{dx} = (\dfrac{7x}{7x+2} * \ln(7x+2))(7x+2)^x$

> Find the derivative of the function $y = (2x \sin x)^{3x}$

5. $\ln y = \ln (3x \sin x)^{3x}$ 
6. $\ln y = 3x * \ln(2x \sin x)$*
7. $\dfrac{d}{dx} \ln(y) = \dfrac{d}{dx} 3x(\ln 2 + \ln x + \ln(sinx))$ 
8. $\dfrac{1}{y} \dfrac{dy}{dx} = 3(\ln 2 + \ln x + \ln(\sin(x))) + 3x (0 + \dfrac{1}{x} + \dfrac{1}{\sin x} * \cos x)$j
9. $\dfrac{dy}{dx} = (3\ln 2 + 3 \ln x + 3\ln \sin(x) + 3\ln(\sin(x) + 3x\cot(x))(2x\sin x)^{3x}$ 
# Chain Rule
$$ \dfrac{d}{dx} f(g(x)) = f'(g(x))*g'(x) $$
## Examples
> Given the function $(x^2+3)^4$, find the derivative.

Using the chain rule, the above function might be described as $f(g(x))$, where $f(x) = x^4$, and $g(x) = x^2 + 3)$.
10. First find the derivative of the outside function function ($f(x) = x^4$):
$$ \dfrac{d}{dx} (x^2 +3)^4 = 4(g(x))^3 ...$$
11. Multiply that by the derivative of the inside function, $g(x)$, or $x^2 + 3$. 
$$ \dfrac{d}{dx} (x^2 + 3)^4 = 4(x^2 + 3)^3 * (2x)$$ 
> Apply the chain rule to $x^4$

If we treat the above as a function along the lines of $f(x) = (x)^4$, and $g(x) = x$, then the chain rule can be used like so:
$$ 4(x)^3 * (1) $$
# Trig Functions
$$ \lim_{x \to 0} \dfrac{\sin x}{x} = 1 $$
$$ \lim_{x \to 0} \dfrac{\cos x - 1}{x} = 0 $$
## Sine
$$ f'(x) = \lim_{h \to 0} \dfrac{\sin(x + h) - sin(x)}{h} $$
Using the sum trig identity, $\sin(x + h)$ can be rewritten as $\sin x \cos h + \cos x \sin h$.

This allows us to simplify, ultimately leading to:
$$ \dfrac{d}{dx} \sin x = \cos x$$
## Cosine
$$ \dfrac{d}{dx} \cos x = -\sin x $$

## Tangent
$$ \dfrac{d}{dx} \tan x = \sec^2x $$
## Secant
$$ \dfrac{d}{dx} \sec x = \sec x * \tan x $$

## Cosecant
$$ \dfrac{d}{dx} \csc x = -\csc x \cot x $$
## Cotangent
$$ \dfrac{d}{dx} \cot x = -\csc^2 x $$

# Implicit Differentiation
- There's a reason differentials are written like a fraction
- $\dfrac{d}{dx} x^2 = \dfrac{d(x^2)}{dx}$, or, "the derivative of $x^2$ with respect to $x$"
- $\dfrac{d}{dx} x = \dfrac{dx}{dx} = 1$ : The derivative of $x$ with respect to $x$ is one
- $\dfrac{d}{dx} y = \dfrac{dy}{dx} = y'$ 
- Given the equation $y = x^2$, $\dfrac{d}{dx} y = \dfrac{dy}{dx} = 2x$.

Given these facts:
12. Let $y$ be some function of $x$
13. $\dfrac{d}{dx} x = 1$
14. $\dfrac{d}{dx} y = \dfrac{dy}{dx}$\

